@@ -1,17 +1,17 @@
 /* rpackage.cc - wrapper for accessing package information
- * 
- * Copyright (c) 2000-2003 Conectiva S/A 
+ *
+ * Copyright (c) 2000-2003 Conectiva S/A
  *               2002-2013 Michael Vogt <mvo@debian.org>
- * 
+ *
  * Author: Alfredo K. Kojima <kojima@conectiva.com.br>
  *         Michael Vogt <mvo@debian.org>
- * 
+ *
  * Portions Taken from Gnome APT
  *   Copyright (C) 1998 Havoc Pennington <hp@pobox.com>
- * 
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -54,7 +54,6 @@
 #include <apt-pkg/configuration.h>
 #include <apt-pkg/tagfile.h>
 #include <apt-pkg/policy.h>
-#include <apt-pkg/sptr.h>
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/cacheiterators.h>
 #include <apt-pkg/pkgcache.h>
@@ -108,11 +107,14 @@ void RPackage::addVirtualPackage(pkgCache::PkgIterator dep)
 
 const char *RPackage::section()
 {
-   const char *s = _package->Section();
-   if (s != NULL)
-      return s;
-   else
-      return _("Unknown");
+   pkgCache::VerIterator ver = (*_depcache)[*_package].CandidateVerIter(*_depcache);
+   if (!ver.end()) {
+      const char *s = ver.Section();
+      if (s != NULL)
+         return s;
+   }
+
+   return _("Unknown");
 }
 
 const char *RPackage::srcPackage()
@@ -125,7 +127,7 @@ const char *RPackage::srcPackage()
       _srcPkg = parser.SourcePkg().empty() ? name() : parser.SourcePkg();
       return _srcPkg.c_str();
    }
- 
+
    return name();
 }
 
@@ -203,6 +205,15 @@ const char *RPackage::availableVersion()
    return State.CandidateVerIter(*_depcache).VerStr();
 }
 
+pkgCache::VerIterator RPackage::availableVersionIter()
+{
+   pkgDepCache::StateCache & State = (*_depcache)[*_package];
+//    if (State.CandidateVer == 0)
+//       return NULL;
+   return State.CandidateVerIter(*_depcache);
+}
+
+
 const char *RPackage::priority()
 {
    pkgCache::VerIterator ver = (*_depcache)[*_package].CandidateVerIter(*_depcache);
@@ -300,7 +311,7 @@ string RPackage::findTagFromPkgRecord(const char *tag)
       // add +1 to ensure we have the double lineline in the buffer
       if (start && sec.Scan(start, len+1))
 	 return sec.FindS(tag);
-   } 
+   }
 
    return string();
 }
@@ -404,11 +415,11 @@ int RPackage::getFlags()
 }
 
 const char* RPackage::name()
-{ 
+{
 #ifdef WITH_APT_MULTIARCH_SUPPORT
    return fullname.c_str();
 #else
-   const char *s = _package->Name(); 
+   const char *s = _package->Name();
    if (s == NULL)
       return "";
    return s;
@@ -520,7 +531,7 @@ vector<DepInformation> RPackage::enumRDeps()
 
       // HACK: we (ab)use the DepType for the dependency type,
       //       but add our own RDepends type that is always the
-      //       last element of DepTypeStr[] 
+      //       last element of DepTypeStr[]
       // FIXME: make this less hacky
       int nr_elements = sizeof(DepTypeStr)/sizeof(char*);
       dep.type = (pkgCache::Dep::DepType)(nr_elements-1);
@@ -578,7 +589,7 @@ bool RPackage::enumAvailDeps(const char *&type, const char *&what,
       return false;
 
    _depI = ver.DependsList();
-   // uninitialized but doesn't matter, they just have to be equal    
+   // uninitialized but doesn't matter, they just have to be equal
    _depStart = _depEnd;
 
    return nextDeps(type, what, pkg, which, summary, satisfied);
@@ -599,7 +610,7 @@ vector<RPackage *> RPackage::getInstalledDeps()
       return deps;
 
    _depI = ver.DependsList();
-   // uninitialized but doesn't matter, they just have to be equal    
+   // uninitialized but doesn't matter, they just have to be equal
 
    pkgCache::DepIterator depIter = _depI;
    while (!depIter.end()) {
@@ -685,7 +696,7 @@ string RPackage::showWhyInstBroken()
 			// TRANSLATORS: dependency error message, example:
 			// "apt 0.5.4 but it is not installable"
                         ioprintf(out, _("\t%s %s but it is not installable"),
-                                 Start.TargetPkg().Name(), 
+                                 Start.TargetPkg().Name(),
 				 requiredVersion.c_str());
                      else
 			// TRANSLATORS: dependency error message, example:
@@ -753,7 +764,7 @@ vector<DepInformation> RPackage::enumDeps(bool useCanidateVersion)
    if(useCanidateVersion || Cur.end())
       Cur = (*_depcache)[*_package].CandidateVerIter(*_depcache);
 
-   // no information found 
+   // no information found
    if(Cur.end())
       return deps;
 
@@ -808,7 +819,7 @@ bool RPackage::isTrusted()
       return false;
    }
    pkgSourceList *Sources=_lister->getCache()->list();
-   std::map<pkgCache::PkgFileIterator, pkgIndexFile*>::iterator it;   
+   std::map<pkgCache::PkgFileIterator, pkgIndexFile*>::iterator it;
    for (pkgCache::VerFileIterator i = Ver.FileList(); i.end() == false; i++)
    {
       pkgIndexFile *Index;
@@ -833,16 +844,16 @@ bool RPackage::isTrusted()
       if (Index->IsTrusted())
          return true;
    }
-   
+
    return false;
 }
 #else
 // with apt-authentication we always trust that the package come from
 // a trusted source
-bool RPackage::isTrusted() 
-{ 
-   return true; 
-};
+bool RPackage::isTrusted()
+{
+   return true;
+}
 #endif
 
 bool RPackage::wouldBreak()
@@ -916,7 +927,6 @@ void RPackage::setRemove(bool purge)
    Fix.Protect(*_package);
    Fix.Remove(*_package);
 
-   Fix.InstallProtect();
    Fix.Resolve(true);
 
    _depcache->SetReInstall(*_package, false);
@@ -932,9 +942,9 @@ string RPackage::getScreenshotFile(pkgAcquire *fetcher, bool thumb)
    descr+=name();
 
    string verstr;
-   if(availableVersion() != NULL) 
+   if(availableVersion() != NULL)
       verstr = availableVersion();
-   
+
    if(verstr.find(':')!=verstr.npos)
       verstr=string(verstr, verstr.find(':')+1);
    char uri[512];
@@ -955,55 +965,14 @@ string RPackage::getScreenshotFile(pkgAcquire *fetcher, bool thumb)
    return filename;
 }
 
-string RPackage::getChangelogURI() 
-{
-   char uri[512];
-   //FIXME: get the supportedOrigins from pkgStatus
-   if(origin() == "Debian") {
-      string prefix;
-      string srcpkg = srcPackage();
-
-      string src_section=section();
-      if(src_section.find('/')!=src_section.npos)
-         src_section=string(src_section, 0, src_section.find('/'));
-      else
-         src_section="main";
-
-      prefix+=srcpkg[0];
-      if(srcpkg.size()>3 && srcpkg[0]=='l' && srcpkg[1]=='i' && srcpkg[2]=='b')
-         prefix=std::string("lib")+srcpkg[3];
-
-      string verstr;
-      if(availableVersion() != NULL) 
-         verstr = availableVersion();
-      
-      if(verstr.find(':')!=verstr.npos)
-         verstr=string(verstr, verstr.find(':')+1);
-
-      snprintf(uri,512,"https://packages.debian.org/changelogs/pool/%s/%s/%s/%s_%s/changelog",
-                               src_section.c_str(),
-                               prefix.c_str(),
-                               srcpkg.c_str(),
-                               srcpkg.c_str(),
-                               verstr.c_str());
-   } else {
-       string pkgfilename = findTagFromPkgRecord("Filename");
-       pkgfilename = pkgfilename.substr(0, pkgfilename.find_last_of('.')) + ".changelog";
-       vector<string> origin_urls = getCandidateOriginSiteUrls();
-       if (origin_urls.size() > 0) 
-          snprintf(uri,512,"http://%s/%s",
-                   origin_urls[0].c_str(),
-                   pkgfilename.c_str());
-   }
-   return string(uri);
-}
-
 string RPackage::getChangelogFile(pkgAcquire *fetcher)
 {
    string descr("Changelog for ");
    descr+=name();
 
-   string uri = getChangelogURI();
+   pkgCache::VerIterator Ver = availableVersionIter();
+   std::string uri = pkgAcqChangelog::URI(Ver);
+   
    // no need to translate this, the changelog is in english anyway
    string filename = RTmpDir()+"/tmp_cl";
 
@@ -1012,6 +981,7 @@ string RPackage::getChangelogFile(pkgAcquire *fetcher)
    //cerr << "**DEBUG** uri: " << uri << endl;
    //cerr << "**DEBUG** filename: " << filename << endl;
 
+
    ofstream out(filename.c_str());
    if(fetcher->Run() == pkgAcquire::Failed) {
       out << "Failed to download the list of changes. " << endl;
@@ -1023,7 +993,10 @@ string RPackage::getChangelogFile(pkgAcquire *fetcher)
       if (filestatus.st_size == 0) {
          out << "This change is not coming from a source that supports changelogs.\n" << endl;
          out << "Failed to fetch the changelog for " << name() << endl;
-         out << "URI was: " << uri << endl;
+         if (uri.empty())
+            out << "URI was empty" << endl;
+         else
+            out << "URI was: " << uri << endl;
       }
    };
    out.close();
@@ -1093,7 +1066,7 @@ void RPackage::setPinned(bool flag)
       out << "Package: " << name() << endl;
       // if the package is not installed, we pin it to the available version
       // and prevent installation of this package this way
-      if(installedVersion() != NULL) 
+      if(installedVersion() != NULL)
 	 out << "Pin: version " << installedVersion() << endl;
       else
 	 out << "Pin: version " << " 0.0 " << endl;
@@ -1105,13 +1078,13 @@ void RPackage::setPinned(bool flag)
       stat(File.c_str(), &stat_buf);
       // create a tmp_pin file in the internal dir
       string filename = RStateDir() + "/.tmp_preferences";
-      FILE *out = fopen(filename.c_str(),"w");
-      if (out == NULL)
-         cerr << "error opening tmpfile: " << filename << endl;
+      FileFd out(filename, FileFd::WriteOnly | FileFd::Create | FileFd::Empty);
+      if (!out.IsOpen()) {
+         _error->DumpErrors();
+      }
       FileFd Fd(File, FileFd::ReadOnly);
       pkgTagFile TF(&Fd);
       if (_error->PendingError() == true) {
-         fclose(out);
          return;
       }
       pkgTagSection Tags;
@@ -1123,19 +1096,14 @@ void RPackage::setPinned(bool flag)
                      ("Invalid record in the preferences file, no Package header"));
             return;
          }
-         if (Name != name()) {
-            TFRewriteData tfrd;
-            tfrd.Tag = 0;
-            tfrd.Rewrite = 0;
-            tfrd.NewTag = 0;
-            TFRewrite(out, Tags, TFRewritePackageOrder, &tfrd);
-            fprintf(out, "\n");
-         }
+         if (Name != name())
+            Tags.Write(out, TFRewritePackageOrder, {});
+         out.Write("\n", 1);
       }
-      fflush(out);
+      out.Flush();
       rename(filename.c_str(), File.c_str());
       chmod(File.c_str(), stat_buf.st_mode);
-      fclose(out);
+      out.Close();
    }
 }
 
@@ -1235,11 +1203,11 @@ bool RPackage::setVersion(string verTag)
 
    return true;
 }
- 
-void RPackage::unsetVersion() 
-{ 
+
+void RPackage::unsetVersion()
+{
    //cout << "set version to " << _defaultCandVer << endl;
-   setVersion(_defaultCandVer); 
+   setVersion(_defaultCandVer);
    _boolFlags &= ~FOverrideVersion;
 }
 
@@ -1448,7 +1416,11 @@ string RPackage::component()
    string res;
 #ifdef WITH_APT_AUTH
    // the apt-secure patch breaks File.Component
-   const char *s = _package->Section();
+   pkgCache::VerIterator ver = (*_depcache)[*_package].CandidateVerIter(*_depcache);
+   const char *s = NULL;
+   if (!ver.end())
+      s = ver.Section();
+
    if(s == NULL)
       return "";
 
@@ -1535,7 +1507,7 @@ _searchPkgFileIter(pkgCache::PkgIterator *Pkg, string label, string release)
    for(Ver = Pkg->VersionList();!Ver.end();Ver++) {
       for(VF = Ver.FileList();!VF.end(); VF++) {
 	 for(PF = VF.File(); !PF.end(); PF++) {
-	    if(!PF.end() && 
+	    if(!PF.end() &&
 	       PF.Label() && string(PF.Label()) == label &&
 	       PF.Origin() && string(PF.Origin()) == label &&
 	       PF.Archive() && PF.Archive() == release) {
@@ -1556,7 +1528,7 @@ string RPackage::getReleaseFileForOrigin(string label, string release)
    pkgCache::PkgFileIterator found = _searchPkgFileIter(_package, label, string(release));
    if (found.end())
       return "";
-   
+
    // search for the matching meta-index
    pkgSourceList *list = _lister->getCache()->list();
    if(list->FindIndex(found, index)) {
